@@ -1,7 +1,7 @@
 # #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # <HTTPretty - HTTP client mock for Python>
-# Copyright (C) <2011-2013>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2011-2015>  Gabriel Falcão <gabriel@nacaolivre.org>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -25,9 +25,9 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 from __future__ import unicode_literals
 
-__version__ = version = '0.8.6'
+__version__ = version = '0.8.14'
 
-from .core import httpretty, httprettified
+from .core import httpretty, httprettified, EmptyRequestHeaders
 from .errors import HTTPrettyError, UnmockedError
 from .core import URIInfo
 
@@ -54,3 +54,34 @@ CONNECT = httpretty.CONNECT
 def last_request():
     """returns the last request"""
     return httpretty.last_request
+
+
+def has_request():
+    """returns a boolean indicating whether any request has been made"""
+    return not isinstance(httpretty.last_request.headers, EmptyRequestHeaders)
+
+
+__all__ = [
+    'last_request',
+    'has_request',
+    'GET',
+    'PUT',
+    'POST',
+    'DELETE',
+    'HEAD',
+    'PATCH',
+    'OPTIONS',
+    'CONNECT',
+    'register_uri',
+    'enable',
+    'disable',
+    'is_enabled',
+    'reset',
+    'Response',
+    'URIInfo',
+    'UnmockedError',
+    'HTTPrettyError',
+    'httpretty',
+    'httprettified',
+    'EmptyRequestHeaders',
+]
